[![pytest](https://github.com/Deltares/hatyan/actions/workflows/pytest.yml/badge.svg?branch=main)](https://github.com/Deltares/hatyan/actions/workflows/pytest.yml)
[![codecov](https://img.shields.io/codecov/c/github/deltares/hatyan.svg?style=flat-square)](https://app.codecov.io/gh/deltares/hatyan?displayType=list)
[![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=Deltares_hatyan&metric=alert_status)](https://sonarcloud.io/dashboard?id=Deltares_hatyan)
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/Deltares/hatyan/HEAD?urlpath=/tree/docs/notebooks)
[![Available on pypi](https://img.shields.io/pypi/v/hatyan.svg)](https://pypi.python.org/pypi/hatyan)
[![Supported versions](https://img.shields.io/pypi/pyversions/hatyan.svg)](https://pypi.org/project/hatyan)
[![Downloads](https://img.shields.io/pypi/dm/hatyan.svg)](https://pypistats.org/packages/hatyan)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.6885342.svg)](https://doi.org/10.5281/zenodo.6885342)

# hatyan

A Python package for harmonic tidal analysis and prediction, based on the FORTRAN version and developed for Rijkswaterstaat. Hatyan also contains methods to derive water level extremes (high and low waters) and it is a dependency to derive the [Kenmerkende Waarden](https://github.com/Deltares-research/kenmerkendewaarden).

## Information

- install with ``pip install hatyan -U``
- [online documentation](https://deltares.github.io/hatyan) with contributing guide, tutorials/examples and an API reference.
- [docs folder](https://github.com/Deltares/hatyan/tree/main/docs) with background information
- Bug or feature request? Create a [GitHub issue](https://github.com/Deltares/hatyan/issues)
